Attribute VB_Name = "basBinHex"
' ---------------------------------------------------------
' Create a Hex-Decimal-Binary conversion table in
' Microsoft Word 97 document format.
'
' Written by Kenneth Ives             kenaso@home.com
'
' This module will create a one page document showing the
' conversion between "Hex-Decimal-Binary" values
' ---------------------------------------------------------

Option Explicit

Private Function Build_Output(arPrnOut() As String)

' ---------------------------------------------------------
' Define variables
' ---------------------------------------------------------
  Dim i As Integer         ' index
  Dim k As Integer         ' index
  Dim iChar As Integer     ' numeric Decimal value
  Dim sHChar As String     ' Hex character
  Dim sBChar As String     ' Binary character
  Dim sDChar As String     ' Decimal character
  Dim sSeparator As String ' column separator
  
' ---------------------------------------------------------
' Initialize variables
' ---------------------------------------------------------
  k = 0
  sSeparator = Space(5)
  
' ---------------------------------------------------------
' process ASCII decimal values 0 to 255
' ---------------------------------------------------------
  For i = 0 To 255
  
      iChar = i                    ' save index to a variable
      sHChar = Get_Hex(iChar)      ' convert to Hex
      sBChar = Get_Binary(iChar)   ' convert to Binary
      
      Select Case i
      
             Case 0 To 63:         ' Column 1 data
                  sDChar = Trim(CStr(iChar))
          
                  ' prefix with 1 or more blanks, if needed
                  If Len(sDChar) = 1 Then
                      sDChar = Space(2) & sDChar
                  ElseIf Len(sDChar) = 2 Then
                      sDChar = " " & sDChar
                  End If
          
                  ' Add the formatted output to the array
                  ReDim Preserve arPrnOut(k)
                  arPrnOut(k) = sHChar & Space(2) & sDChar & Space(2) & sBChar
                  k = k + 1
                  If k > 63 Then k = 0
                  
             Case 64 To 127:      ' Column 2 data
                  sDChar = Trim(CStr(iChar))
                  ' prefix with a blank, if needed
                  If Len(sDChar) = 2 Then sDChar = " " & sDChar
                
                  ' Add the formatted output to the array
                  arPrnOut(k) = arPrnOut(k) & sSeparator & sHChar & Space(2) & _
                                sDChar & Space(2) & sBChar
                  k = k + 1
                  If k > 63 Then k = 0
          
             Case 128 To 191:     ' Column 3 data
                  sDChar = Trim(CStr(iChar))
                  ' prefix with a blank, if needed
                  If Len(sDChar) = 2 Then sDChar = " " & sDChar
          
                  ' Add the formatted output to the array
                  arPrnOut(k) = arPrnOut(k) & sSeparator & sHChar & Space(2) & _
                                sDChar & Space(2) & sBChar
                  k = k + 1
                  If k > 63 Then k = 0
          
             Case 192 To 255:     ' Column 4 data
                  
                  sDChar = Trim(CStr(iChar))
                  ' prefix with a blank, if needed
                  If Len(sDChar) = 2 Then sDChar = " " & sDChar
                    
                  ' Add the formatted output to the array
                  arPrnOut(k) = arPrnOut(k) & sSeparator & sHChar & Space(2) & _
                                sDChar & Space(2) & sBChar
                  k = k + 1
                  If k > 63 Then k = 0
      End Select
  Next
  
End Function

Private Function Get_Hex(iDecValue As Integer) As String

' ---------------------------------------------------------
' Define variables
' ---------------------------------------------------------
  Dim sTmp As String

' ---------------------------------------------------------
' Convert the input value to Hex
' ---------------------------------------------------------
  sTmp = ""
  sTmp = Trim(Hex(iDecValue))

' ---------------------------------------------------------
' if after hex conversion, the length is only one
' char then prefix it with a zero
' ---------------------------------------------------------
  If Len(sTmp) < 2 Then sTmp = "0" & sTmp

' ---------------------------------------------------------
' Return the Hex character
' ---------------------------------------------------------
  Get_Hex = sTmp

End Function

Private Function Get_Binary(iInComing As Integer) As String

' ---------------------------------------------------------
' Written by Kenneth Ives             kenaso@home.com
'
' convert an integer value to its binary equivilent
' ---------------------------------------------------------

' ---------------------------------------------------------
' Define variables
' ---------------------------------------------------------
  Dim iDecValue As Integer
  Dim iBitCnt As Integer
  Dim iBitValue As Integer
  Dim iCurrBit As Integer
  Dim sTmp As String

' ---------------------------------------------------------
' Initialize variables
' ---------------------------------------------------------
  iDecValue = iInComing
  iBitCnt = 0
  iBitValue = 128
  sTmp = ""

' ---------------------------------------------------------
' Parse the incoming integer and determine which bits
' should be turned on
' ---------------------------------------------------------
  Do
      ' Increment the bit count
      iBitCnt = iBitCnt + 1

      ' divide the input integer by the current
      ' bit value.  Starts at 128
      iCurrBit = Int(iDecValue / iBitValue)

      ' if the results are greater than zero then
      ' a "1" is placed in that bit position; otherwise,
      ' a "0" will be placed there
      If iCurrBit > 0 Then
    
          ' append a "1" to the string
          sTmp = sTmp & "1"

          ' subtract the current bit value
          ' from the input integer
          iDecValue = iDecValue - iBitValue
      Else
          ' append a "0" to the string
          sTmp = sTmp & "0"
      End If
    
      ' Decrement the Bit value by dividing by 2
      iBitValue = Int(iBitValue / 2)
    
  Loop Until iBitCnt = 8

' ---------------------------------------------------------
' REturn the binary expression
' ---------------------------------------------------------
  Get_Binary = sTmp

End Function

Private Sub Load_Into_Word(arPrnOut() As String)

' ---------------------------------------------------------
' Define variables
' ---------------------------------------------------------
  Dim k As Integer
  Dim sHeader1 As String   ' Header line 1
  Dim sHeader2 As String   ' Header line 2
  Dim Wrd As Object        ' MS Word basic object
  Dim MyRange As Object    ' MS Word selected range
  
  Const TITLE1 As String = "Hex Dec    Binary"
  Const TITLE2 As String = "-----------------"

' ---------------------------------------------------------
' Initialize variables
' ---------------------------------------------------------
  sHeader1 = TITLE1 & Space(5) & TITLE1 & Space(5) & TITLE1 & Space(5) & TITLE1 & vbCrLf
  sHeader2 = TITLE2 & Space(5) & TITLE2 & Space(5) & TITLE2 & Space(5) & TITLE2 & vbCrLf
  
' ---------------------------------------------------------
' make sure the objects are clear
' ---------------------------------------------------------
  Set Wrd = Nothing
  Set MyRange = Nothing
  
' ---------------------------------------------------------
' Prepare MS Word 97 to accept input of data
' ---------------------------------------------------------
  Set Wrd = CreateObject("Word.Basic")
  Wrd.FileNewDefault
  
' ---------------------------------------------------------
' Define the layout of this document
' ---------------------------------------------------------
  With ActiveDocument.PageSetup
       .LineNumbering.Active = False
       .Orientation = wdOrientPortrait
       .TopMargin = InchesToPoints(0.5)
       .BottomMargin = InchesToPoints(0.5)
       .LeftMargin = InchesToPoints(0.75)
       .RightMargin = InchesToPoints(0.75)
       .Gutter = InchesToPoints(0)
       .HeaderDistance = InchesToPoints(0.5)
       .FooterDistance = InchesToPoints(0.5)
       .PageWidth = InchesToPoints(8.5)
       .PageHeight = InchesToPoints(11)
       .FirstPageTray = wdPrinterDefaultBin
       .OtherPagesTray = wdPrinterDefaultBin
       .SectionStart = wdSectionNewPage
       .OddAndEvenPagesHeaderFooter = False
       .DifferentFirstPageHeaderFooter = False
       .VerticalAlignment = wdAlignVerticalCenter
       .SuppressEndnotes = False
       .MirrorMargins = False
  End With

' ---------------------------------------------------------
' Load the data into Word
' ---------------------------------------------------------
  With Wrd
       .Insert sHeader1
       .Insert sHeader2
        For k = 0 To 63
            ' Load all four columns of data
            ' into the Word document
            .Insert arPrnOut(k) & vbCrLf
        Next
  End With
  
' ---------------------------------------------------------
' Define the font for this document
' ---------------------------------------------------------
  Set MyRange = ActiveDocument.Range(Start:=0, End:=0) ' get everything
  With MyRange
       .WholeStory
       .Font.Name = "Courier New"
       .Font.Size = 9
       .ParagraphFormat.Alignment = wdAlignParagraphCenter
  End With
  
' ---------------------------------------------------------
' Display the Word application
' ---------------------------------------------------------
  Wrd.AppShow
  
End Sub

Public Sub TEST()

' ---------------------------------------------------------
' Create a Hex-Decimal-Binary conversion table in
' Microsoft Word 97 document format.
'
' Written by Kenneth Ives             kenaso@home.com
'
' This module will create a one page document showing the
' conversion between "Hex-Decimal-Binary" values.
'
' Rename this to "Main" and press F5 to execute.
' ---------------------------------------------------------

' ---------------------------------------------------------
' Define variables
' ---------------------------------------------------------
  Dim arPrnOut() As String     ' array to hold output lines
  
' ---------------------------------------------------------
' Load the array with data
' ---------------------------------------------------------
  Build_Output arPrnOut()
  
' ---------------------------------------------------------
' unLoad the array into a Word document
' ---------------------------------------------------------
  Load_Into_Word arPrnOut()
  
' ---------------------------------------------------------
' Terminate Visual Basic
' ---------------------------------------------------------
  End

End Sub

